netapp_ontap.models.oracle_on_nfs API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.oracle_on_nfs`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class OracleOnNfsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the OracleOnNfs object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `archive_log GET POST PATCH`

    The archive_log field of the oracle_on_nfs.

  `db GET POST PATCH`

    The db field of the oracle_on_nfs.

  `nfs_access GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `ora_home GET POST PATCH`

    The ora_home field of the oracle_on_nfs.

  `protection_type GET POST PATCH`

    The protection_type field of the oracle_on_nfs.

  `redo_log GET POST PATCH`

    The redo_log field of the oracle_on_nfs.